==> edu-classlib1.6.1.tar.gz: TaskFileReader.java <==
package jp.ac.takushoku_u.cs.*;
import java.io.*;
import java.util.ArrayList;

/**
 *TaskFileReader饹CSVե,LFGեɤ߹,°ٴؿ򻻽
 *뤿Υ饹Ǥ
 *@version 1.0.0
 *@author ϸ (Kawahara Shinji)
 */
/*
 *ǽ 2005ǯ0613
 */
public final class TaskFileReader{

    /**
     *ɤ߹Ǥꤹ
     */
    private static final double READER_DOUBLE_TRUE = 1.0;
    
    
    /**
     *CSVե˳ǼƤǤArithmeticMatrix֤ޤ
     */
    public static final ArithmeticMatrix getCsvArithmeticMatrixReader(String filename)throws java.io.FileNotFoundException,java.io.IOException{
      
	String ret[] = getLines(filename);
	ArithmeticMatrix mat;
	/*Կ*/
	int row = ret.length;

	/**/
	String col_data[];
	col_data = ret[0].split(",");
	int col = col_data.length;

	double [][]sequ = new double[row][col];
	String data[];
	try{
	    for(int i=0; i<ret.length;i++){
		data = ret[i].split(",");
		for(int j=0; j<data.length; j++){
		    sequ[i][j] = Double.valueOf(data[j]);
		}
	    }
	}catch(ArrayIndexOutOfBoundsException e){}

	mat = new ArithmeticMatrix(sequ);
	return mat;
	
    }
   
 /**
    /*CSVե˳ǼƤǤdouble󼡸֤ޤ
 */
    public static final double[][] getCsvTwoDoubleArray(String filename){
	String ret[] = getLines(filename);

	/*Կ*/
	int row = ret.length;

	/**/
	String col_data[];
	col_data = ret[0].split(",");
	int col = col_data.length;

	double [][]sequ = new double[row][col];

	String data[];
       	try{
	    for(int i=0; i<ret.length; i++){
		data = ret[i].split(",");
		for(int j=0; j<data.length; j++){
		 sequ[i][j] = Double.valueOf(data[j]);
	       
		}
	    }
	}catch(ArrayIndexOutOfBoundsException e){}
	
	return sequ;       
    }
    
    /**
     *CSVեηSequence˳Ǽޤ
     */
    public static final Sequence getSequence(String filename,int Student){
	String ret[] = getLines(filename);
	ArithmeticMatrix mat;
	/*Կ*/
	int row = ret.length;
	
	/**/
	String col_data[];
	col_data = ret[0].split(",");
	int col = col_data.length;
	
	double [][]sequ = new double[row][col];
	String data[];
	try{
	    for(int i=0; i<ret.length;i ++){
		data = ret[i].split(",");
		for(int j=0; j<data.length; j++){
		    sequ[i][j] = Double.valueOf(data[j]);
		}
	    }
	}catch(ArrayIndexOutOfBoundsException e){}
	
	int[] sdata = new int[col];
	for(int i=0; i<col; i++){
	    sdata[i] = (int)(sequ[Student-1][i]-1);
	}
	Sequence sq = new Sequence(sdata);
	return sq;
    }
    /**    
     *LFGե˳ǼƤǤArithmeticMatrix֤ޤ
     */
    public static final ArithmeticMatrix getLfgArithmeticMatrixReader(String filename)throws java.io.FileNotFoundException,java.io.IOException{
	FileReader fr;
	ArithmeticMatrix mat;
	try{
	    fr = new FileReader(filename);
	    BufferedReader in = new BufferedReader(fr);
	
	    int row;
	    int col;
	    boolean flag;
	    String s;
	    s = in.readLine();
	    mat = new ArithmeticMatrix(Integer.parseInt(s),Integer.parseInt(s),1);

	    while((s = in.readLine())!=null){
	       
		row = 0;
		col = 0;
		flag = true;
		for(int i=0; i<s.length(); i++){
		    if(s.charAt(i) != ' ' && flag){
			row = row*10 + Character.getNumericValue(s.charAt(i));
		    }
		    else if(s.charAt(i) != ' ' && (flag == false)){
			col = col*10 + Character.getNumericValue(s.charAt(i));
		    }
		    else{
			flag = false;
		    }
		}
		mat.setCell(row-1, col-1, READER_DOUBLE_TRUE);
	    }
	}
	catch(NotElementException e){
	    throw new NotElementException(e+"");
	}
	return mat;
    }

    
    
     
  
    /**
     *եɤ߹߰󤺤ĳǼޤ
     */
    
    private static String[] getLines(String fileName){

	ArrayList list = new ArrayList();
	try{
	    BufferedReader br = new BufferedReader(new InputStreamReader(new FileInputStream(fileName)));
	    String line = null;

	    while((line = br.readLine()) != null){
		list.add(line);
	    }
	    br.close();
	}catch(IOException err){}
    
	return(String[]) list.toArray(new String[list.size()]);
    }
}

==> edu-classlib1.7.tar.gz: TaskFileReader.java <==
package jp.ac.takushoku_u.cs;
import java.io.*;
import java.util.ArrayList;

/**
 *TaskFileReader饹CSVե,LFGեɤ߹,°ٴؿ򻻽
 *뤿Υ饹Ǥ
 *@version 1.0.0
 *@author ϸ (Kawahara Shinji)
 */
/*
 *ǽ 2005ǯ0613
 */
public final class TaskFileReader{

    /**
     *ɤ߹Ǥꤹ
     */
    private static final double READER_DOUBLE_TRUE = 1.0;
    
    
    /**
     *CSVե˳ǼƤǤArithmeticMatrix֤ޤ
     * @param filename CSVΥե
     * @return Ǥݻܥޥȥꥯ
     */
    public static final ArithmeticMatrix getCsvArithmeticMatrixReader(String filename)throws java.io.FileNotFoundException,java.io.IOException{
      
	String ret[] = getLines(filename);
	ArithmeticMatrix mat;
	/*Կ*/
	int row = ret.length;

	/**/
	String col_data[];
	col_data = ret[0].split(",");
	int col = col_data.length;

	double [][]sequ = new double[row][col];
	String data[];
	try{
	    for(int i=0; i<ret.length;i++){
		data = ret[i].split(",");
		for(int j=0; j<data.length; j++){
		    sequ[i][j] = Double.parseDouble(data[j]);
		}
	    }
	}catch(ArrayIndexOutOfBoundsException e){}

	mat = new ArithmeticMatrix(sequ);
	return mat;
	
    }
   
/**
/*CSVե˳ǼƤǤdouble󼡸֤ޤ
 * @param filename CSVΥե
 * @return Ǥݻ󼡸
 */
    public static final double[][] getCsvTwoDoubleArray(String filename){
	String ret[] = getLines(filename);

	/*Կ*/
	int row = ret.length;

	/**/
	String col_data[];
	col_data = ret[0].split(",");
	int col = col_data.length;

	double [][]sequ = new double[row][col];

	String data[];
       	try{
	    for(int i=0; i<ret.length; i++){
		data = ret[i].split(",");
		for(int j=0; j<data.length; j++){
		 sequ[i][j] = Double.parseDouble(data[j]);
	       
		}
	    }
	}catch(ArrayIndexOutOfBoundsException e){}
	
	return sequ;       
    }
    
    /**
     *CSVեηSequence˳Ǽޤ
     * @param filename CSVΥե
     * @param Student ֹ
     * @return β
     */
    public static final Sequence getSequence(String filename,int Student){
	String ret[] = getLines(filename);
	ArithmeticMatrix mat;
	/*Կ*/
	int row = ret.length;
	
	/**/
	String col_data[];
	col_data = ret[0].split(",");
	int col = col_data.length;
	
	double [][]sequ = new double[row][col];
	String data[];
	try{
	    for(int i=0; i<ret.length;i ++){
		data = ret[i].split(",");
		for(int j=0; j<data.length; j++){
		    sequ[i][j] = Double.parseDouble(data[j]);
		}
	    }
	}catch(ArrayIndexOutOfBoundsException e){}
	
	int[] sdata = new int[col];
	for(int i=0; i<col; i++){
	    sdata[i] = (int)(sequ[Student-1][i]-1);
	}
	Sequence sq = new Sequence(sdata);
	return sq;
    }
    /**    
     *LFGե˳ǼƤǤArithmeticMatrix֤ޤ
     * @param filename LFGե
     * @return Ǥݻܥޥȥꥯ
     * @exception  NotElementException ꤵ줿¸ߤʤ
     */
    public static final ArithmeticMatrix getLfgArithmeticMatrixReader(String filename)throws java.io.FileNotFoundException,java.io.IOException{
	FileReader fr;
	ArithmeticMatrix mat;
	try{
	    fr = new FileReader(filename);
	    BufferedReader in = new BufferedReader(fr);
	
	    int row;
	    int col;
	    boolean flag;
	    String s;
	    s = in.readLine();
	    mat = new ArithmeticMatrix(Integer.parseInt(s),Integer.parseInt(s),1);

	    while((s = in.readLine())!=null){
	       
		row = 0;
		col = 0;
		flag = true;
		for(int i=0; i<s.length(); i++){
		    if(s.charAt(i) != ' ' && flag){
			row = row*10 + Character.getNumericValue(s.charAt(i));
		    }
		    else if(s.charAt(i) != ' ' && (flag == false)){
			col = col*10 + Character.getNumericValue(s.charAt(i));
		    }
		    else{
			flag = false;
		    }
		}
		mat.setCell(row-1, col-1, READER_DOUBLE_TRUE);
	    }
	}
	catch(NotElementException e){
	    throw new NotElementException(e+"");
	}
	return mat;
    }

    
    
     
  
    /**
     *եɤ߹߰󤺤ĳǼޤ
     */
    
    private static String[] getLines(String fileName){

	ArrayList list = new ArrayList();
	try{
	    BufferedReader br = new BufferedReader(new InputStreamReader(new FileInputStream(fileName)));
	    String line = null;

	    while((line = br.readLine()) != null){
		list.add(line);
	    }
	    br.close();
	}catch(IOException err){}
    
	return(String[]) list.toArray(new String[list.size()]);
    }
}
